summaryrefslogtreecommitdiffstats
path: root/kmail/encodingdetector.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /kmail/encodingdetector.cpp
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmail/encodingdetector.cpp')
-rw-r--r--kmail/encodingdetector.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kmail/encodingdetector.cpp b/kmail/encodingdetector.cpp
index df595b36..cc19e3b1 100644
--- a/kmail/encodingdetector.cpp
+++ b/kmail/encodingdetector.cpp
@@ -1,5 +1,5 @@
/*
- This file was taken from the KDE 4.x libraries and backported to Qt 3.
+ This file was taken from the KDE 4.x libraries and backported to TQt 3.
Copyright (C) 1999 Lars Knoll (knoll@kde.org)
Copyright (C) 2003 Dirk Mueller (mueller@kde.org)
@@ -51,7 +51,7 @@
// Multiple scripts per language were removed and the entries were reordered so
// that simple substring matching will work. For example, bam was put before ba
// so that the first match will be likely the right match. Otherwise "ba" would
// match "bam" but we would have to search on to find "bam" which is what we want.
// The original file is called pango-script-lang-table.h
/* pango-script-lang-table.h:
@@ -856,7 +856,7 @@ bool EncodingDetector::setEncoding(const char *_encoding, EncodingChoiceSource t
}
else
{
- //QString->QTextCodec
+ //TQString->TQTextCodec
enc = enc.lower();
// hebrew visually ordered
@@ -880,7 +880,7 @@ bool EncodingDetector::setEncoding(const char *_encoding, EncodingChoiceSource t
if (codec->mibEnum() == Mib8859_8)
{
//We do NOT want to use Qt's TQHebrewCodec, since it tries to reorder itself.
codec = TQTextCodec::codecForName("iso8859-8-i");
// visually ordered unless one of the following
@@ -1059,13 +1059,13 @@ bool EncodingDetector::analyze(const char *data, int len)
TQCString str( ptr, (end-ptr)+1);
str = str.lower();
int pos=0;
- //if( (pos = str.find("http-equiv", pos)) == -1) break;
- //if( (pos = str.find("content-type", pos)) == -1) break;
- if( (pos = str.find("charset")) == -1)
+ //if( (pos = str.tqfind("http-equiv", pos)) == -1) break;
+ //if( (pos = str.tqfind("content-type", pos)) == -1) break;
+ if( (pos = str.tqfind("charset")) == -1)
continue;
pos+=6;
// skip to '='
- if( (pos = str.find('=', pos)) == -1)
+ if( (pos = str.tqfind('=', pos)) == -1)
continue;
// skip whitespace before encoding itself
@@ -51,7 +51,7 @@
// that simple substring matching will work. For example, bam was put before ba
// so that the first match will be likely the right match. Otherwise "ba" would
-// match "bam" but we would have to search on to find "bam" which is what we want.
+// match "bam" but we would have to search on to tqfind "bam" which is what we want.
// The original file is called pango-script-lang-table.h
/* pango-script-lang-table.h:
@@ -880,7 +880,7 @@ bool EncodingDetector::setEncoding(const char *_encoding, EncodingChoiceSource t
if (codec->mibEnum() == Mib8859_8)
{
- //We do NOT want to use Qt's TQHebrewCodec, since it tries to reorder itself.
+ //We do NOT want to use TQt's TQHebrewCodec, since it tries to reorder itself.
codec = TQTextCodec::codecForName("iso8859-8-i");
// visually ordered unless one of the following